@@ -34,7 +34,7 @@ class Config:
     configuration_parser.read(self.configuration_file_path)
 
     for section in ("slaprunner", "slapos", "slapproxy", "slapformat",
-                    "sshkeys_authority", "gitclient", "cloud9_IDE"):
+                    "sshkeys_authority", "gitclient"):
       configuration_dict = dict(configuration_parser.items(section))
       for key in configuration_dict:
         if not getattr(self, key, None):
@@ -126,7 +126,8 @@ def serve(config):
   if not os.path.exists(software_link):
     os.mkdir(software_link)
   setHandler()
-  config.logger.info('Running slapgrid...')
+  app.logger.addHandler(config.logger)
+  app.logger.info('Running slapgrid...')
   if app.config['auto_deploy_instance'] in TRUE_VALUES:
     runInstanceWithLock(app.config)
   config.logger.info('Done.')
