@@ -20,7 +20,8 @@ import shutil
 import time
 import unittest
 
-from slapos.runner.utils import (getProfilePath, getSession, isInstanceRunning,
+from slapos.runner.utils import (getProfilePath, getRcode,
+                                 getSession, isInstanceRunning,
                                  isSoftwareRunning, startProxy,
                                  isSoftwareReleaseReady,
                                  runSlapgridUntilSuccess,
@@ -47,7 +48,7 @@ class Config:
     """
     Set options given by parameters.
     """
-    self.configuration_file_path = os.path.abspath(os.environ.get('CONFIG_FILE_PATH'))
+    self.configuration_file_path = os.path.abspath(os.environ.get('RUNNER_CONFIG'))
 
     # Load configuration file
     configuration_parser = ConfigParser.SafeConfigParser()
@@ -55,7 +56,7 @@ class Config:
     # Merges the arguments and configuration
 
     for section in ("slaprunner", "slapos", "slapproxy", "slapformat",
-                    "sshkeys_authority", "gitclient", "cloud9_IDE"):
+                    "sshkeys_authority", "gitclient"):
       configuration_dict = dict(configuration_parser.items(section))
       for key in configuration_dict:
         if not getattr(self, key, None):
@@ -69,7 +70,6 @@ class SlaprunnerTestCase(unittest.TestCase):
     views.app.config['TESTING'] = True
     self.users = ["slapuser", "slappwd", "slaprunner@nexedi.com", "SlapOS web runner"]
     self.updateUser = ["newslapuser", "newslappwd", "slaprunner@nexedi.com", "SlapOS web runner"]
-    self.rcode = "41bf2657"
     self.repo = 'http://git.erp5.org/repos/slapos.git'
     self.software = "workspace/slapos/software/"  # relative directory fo SR
     self.project = 'slapos'  # Default project name
@@ -103,8 +103,9 @@ class SlaprunnerTestCase(unittest.TestCase):
     self.app = views.app.test_client()
     self.app.config = views.app.config
     #Create password recover code
-    with open(os.path.join(views.app.config['etc_dir'], '.rcode'), 'w') as rpwd:
-      rpwd.write(self.rcode)
+    parser = ConfigParser.ConfigParser()
+    parser.read(self.app.config['knowledge0_cfg'])
+    self.rcode = parser.get('public', 'recovery-code')
     #Create config.json
     json_file = os.path.join(views.app.config['etc_dir'], 'config.json')
     if not os.path.exists(json_file):
@@ -118,7 +119,6 @@ class SlaprunnerTestCase(unittest.TestCase):
 
   def tearDown(self):
     """Remove all test data"""
-    os.unlink(os.path.join(self.app.config['etc_dir'], '.rcode'))
     project = os.path.join(self.app.config['etc_dir'], '.project')
     users = os.path.join(self.app.config['etc_dir'], '.users')
 
@@ -243,8 +243,9 @@ class SlaprunnerTestCase(unittest.TestCase):
     encode.update(self.updateUser[0], self.updateUser[1])
     assert self.updateUser[0] in open(htpasswd).read()
 
-  def test_startProxy(self):
+  def test_startStopProxy(self):
     """Test slapproxy"""
+    self.stopSlapproxy()
     self.proxyStatus(False)
     startProxy(self.app.config)
     self.proxyStatus(True)
@@ -433,6 +434,7 @@ class SlaprunnerTestCase(unittest.TestCase):
     Sofware Instance if it has been deployed yet"""
     # Test that SR won't be deployed with auto_deploy=False
     self.app.config['auto_deploy'] = False
+    self.app.config['autorun'] = False
     project = open(os.path.join(self.app.config['etc_dir'],
                   '.project'), "w")
     project.write(self.software + 'slaprunner-test')
@@ -446,6 +448,7 @@ class SlaprunnerTestCase(unittest.TestCase):
     self.assertEqual(response, "2")
     # Test that the new call to isSoftwareReleaseReady
     # doesn't overwrite the previous installed one
+    killRunningProcess('slapgrid-sr')
     completed_path = os.path.join(self.app.config['runner_workdir'],
         'softwareLink', 'slaprunner-test', '.completed')
     completed_text = ".completed file: test"
