@@ -11,7 +11,7 @@ $(document).ready(function () {
         config,
         files,
         working_node = null,
-        editorlist = Array(),
+        editorlist = [],
         editorIndex = 0,
         saveTimeOut = null,
         softwareDisplay = true,
@@ -23,12 +23,13 @@ $(document).ready(function () {
         ajaxResult = false,
         clipboardNode = null,
         pasteMode = null,
-        favourite_list = new Array(),
+        favourite_list = [],
         editorWidth = $("#code").css("width"),
         beforeunload_warning_set = 0,
         base_path = function () {
             return softwareDisplay ? currentProject : 'workspace/';
         };
+    
     var MAX_TABITITLE_WIDTH = 126;
     var TAB_EXTRA_WIDTH = 25;
     var MIN_TABITEM_WIDTH = 61; //The minimum size of tabItem
@@ -65,11 +66,12 @@ $(document).ready(function () {
         .done(function(data) {
           var editor = editorlist[hash].editor;
           if (data.code === 1) {
-            editor.getSession().setValue(data.result);
+            editor.session.setValue(data.result);
             $(activeSpan).html(file.replace(/^.*(\\|\/|\:)/, ''));
             var mode = modelist.getModeForPath(file);
-            editor.getSession().modeName = mode.name;
-            editor.getSession().setMode(mode.mode);
+            editor.session.modeName = mode.name;
+            editor.session.setMode(mode.mode);
+            editor.session.getUndoManager().reset();
             editorlist[hash].busy = false;
             status = true;
           } else {
@@ -103,7 +105,7 @@ $(document).ready(function () {
           url: $SCRIPT_ROOT + '/saveFileContent',
           data: {
               file: editorlist[hash].path,
-              content: editorlist[hash].editor.getSession().getValue()
+              content: editorlist[hash].editor.session.getValue()
           }})
         .done(function(data) {
           if (data.code === 1) {
@@ -156,7 +158,7 @@ $(document).ready(function () {
       if (addTab) {
         numberTab++;
       }
-      if (numberTab == 0) {
+      if (numberTab === 0) {
         return width;
       }
       var tabBarWidth = $(".box_header").width() - $(".box_header ul").width();
@@ -274,17 +276,20 @@ $(document).ready(function () {
       //Init Ace editor!!
 
       editor.setTheme("ace/theme/crimson_editor");
-      editor.getSession().setMode("ace/mode/text");
-      editor.getSession().setTabSize(2);
-      editor.getSession().setUseSoftTabs(true);
+      editor.session.setMode("ace/mode/text");
+      editor.session.setTabSize(2);
+      editor.session.setUseSoftTabs(true);
       editor.renderer.setHScrollBarAlwaysVisible(false);
 
       editorlist[hash] = {editor: editor, changed: false, path: path,
                           isOpened: false, busy: true};
-      editor.on("change", function (e) {
+      editor.on('input', function (e) {
         var activeToken = getActiveToken(),
             activeSpan = getActiveTabTitleSelector();
         if (!editorlist[activeToken].busy && !editorlist[activeToken].changed) {
+          if (!editorlist[activeToken].editor.session.getUndoManager().hasUndo()){
+            return;
+          }
           editorlist[activeToken].changed = true;
           $(activeSpan).html("*" + $(activeSpan).html());
           if(beforeunload_warning_set === 0) {
@@ -365,8 +370,14 @@ $(document).ready(function () {
             success: function (data) {
                 if (data.code === 1) {
                     filename = path.replace(/^.*(\\|\/|\:)/, '');
-                    $("#info").empty();
-                    $("#info").html("Md5sum for file [" + filename + "]: " + data.result);
+                    if ( $("body").hasClass("fullScreen") ) {
+                      $("#error").Popup("Md5sum for file [" + filename + "]:<br/>" 
+                              + "<b>" + data.result + "</b>", {type: 'confirm'});
+                    }
+                    else {
+                      $("#info").empty();
+                      $("#info").html("Md5sum for file [" + filename + "]: " + data.result);
+                    }
                 } else {
                     $("#error").Popup(data.result, {type: 'error', duration: 5000});
                 }
@@ -470,7 +481,7 @@ $(document).ready(function () {
               if (ajaxResult){
                 if (dataForSend.opt === 14){
                   node.load(true);
-                  node.toggleExpanded();
+                  expandAfterLoad (node, true);
                 }
                 else if (node.isExpanded()){
                   node.addChildren(cb);
@@ -482,7 +493,7 @@ $(document).ready(function () {
           }
           break;
       }
-    };
+    }
 
     function manageMenu (srcElement, menu){
       /*if (!srcElement.hasClass('fancytree-node')){
@@ -493,7 +504,7 @@ $(document).ready(function () {
       node.setFocus();
       node.setActive();
       if (srcElement.hasClass('fancytree-folder')){
-        menu.disableContextMenuItems("#edit,#view,#md5sum,#favorite");
+        menu.disableContextMenuItems("#edit,#view,#md5sum");
       }
       else{
         menu.disableContextMenuItems("#nfile,#nfolder,#refresh,#paste,#ufile");
@@ -551,21 +562,21 @@ $(document).ready(function () {
             data: {opt: 9, filename: node.title, dir: directory},
             success: function (data) {
               $("#inline_content").empty();
-        			$("#inline_content").append('<div class="main_content"><pre id="editorViewer"></pre></div>');
+              $("#inline_content").append('<div class="main_content"><pre id="editorViewer"></pre></div>');
               viewer = ace.edit("editorViewer");
               viewer.setTheme("ace/theme/crimson_editor");
 
               var mode = modelist.getModeForPath(node.data.path);
-              viewer.getSession().modeName = mode.name;
-              viewer.getSession().setMode(mode.mode);
-              viewer.getSession().setTabSize(2);
-              viewer.getSession().setUseSoftTabs(true);
+              viewer.session.modeName = mode.name;
+              viewer.session.setMode(mode.mode);
+              viewer.session.setTabSize(2);
+              viewer.session.setUseSoftTabs(true);
               viewer.renderer.setHScrollBarAlwaysVisible(false);
               viewer.setReadOnly(true);
-        			$("#inlineViewer").colorbox({inline:true, width: "847px", onComplete:function(){
-        				viewer.getSession().setValue(data);
-        			}, title: "Content of file: " + node.title});
-  			      $("#inlineViewer").click();
+              $("#inlineViewer").colorbox({inline:true, width: "847px", onComplete:function(){
+                viewer.session.setValue(data);
+              }, title: "Content of file: " + node.title});
+              $("#inlineViewer").click();
             }
           });
           break;
@@ -574,11 +585,11 @@ $(document).ready(function () {
           break;
         case "refresh":
           node.load(true);
-          node.toggleExpanded();
+          expandAfterLoad (node, true);
           break;
         case "nfolder":
           var newName = window.prompt('Please Enter the folder name: ');
-          if (newName == null || newName.length < 1) {
+          if (newName === null || newName.length < 1) {
               return;
           }
           var dataForSend = {
@@ -590,13 +601,13 @@ $(document).ready(function () {
           request.always(function() {
             if (ajaxResult){
               node.load(true);
-              node.toggleExpanded();
+              expandAfterLoad (node, true);
             }
           });
           break;
         case "nfile":
           var newName = window.prompt('Please Enter the file name: ');
-          if (newName == null || newName.length < 1) {
+          if (newName === null || newName.length < 1) {
               return;
           }
           var dataForSend = {
@@ -608,7 +619,7 @@ $(document).ready(function () {
           request.always(function() {
             if (ajaxResult){
               node.load(true);
-              node.toggleExpanded();
+              expandAfterLoad (node, true);
             }
           });
           break;
@@ -630,7 +641,7 @@ $(document).ready(function () {
           break;
         case "rename":
           var newName = window.prompt('Please enter the new name: ', node.title);
-          if (newName == null) {
+          if (newName === null) {
               return;
           }
           dataForSend = {
@@ -652,14 +663,18 @@ $(document).ready(function () {
               }
               else {
                 node.getParent().load(true);
-                node.toggleExpanded();
+                expandAfterLoad (node, true);
               }
             }
           });
 
           break;
         case "favorite":
-          addToFavourite(node.data.path);
+          var nodePath = node.data.path;
+          if (node.isFolder()) {
+            nodePath = (nodePath.substr(-1) === '/') ? nodePath : nodePath + '/';
+          }
+          addToFavourite(nodePath);
           break;
         case "ufile":
           $.colorbox.remove();
@@ -675,7 +690,7 @@ $(document).ready(function () {
           return;
         }
       }, manageMenu);
-    };
+    }
 
     // --- Init fancytree during startup ----------------------------------------
     function initTree(tree, path, key){
@@ -759,14 +774,85 @@ $(document).ready(function () {
         }
       });
     }
+    
+    function expandAfterLoad (node, toState) {
+      /*Expand node after the call of load.
+        toState if true of false*/
+      setTimeout(function () {
+        if (node.isLoaded()) {
+          node.setExpanded(toState);
+        }
+        else {
+          expandAfterLoad (node, toState);
+        }
+      },300);
+    }
+    
+    function loadNodeAndExpand(tree, subNode, node, position, loading) {
+      var i = position, nextNode = null;
+      if (i >= subNode.length ) {
+        if (node) {
+          node.setActive(true);
+          node.scrollIntoView();
+        }
+        return;
+      }
+      if (!loading) {
+        var childList = (i === 1 ) ? tree.toDict() : node.getChildren();
+        for (var j=0; j<childList.length; j++){
+          if (childList[j].title === subNode[i]) {
+            nextNode = (i === 1 ) ? tree.getNodeByKey(childList[j].key) : childList[j];
+            break;
+          }
+        }
+      }
+      else {
+        nextNode = node;
+      }
+      if (nextNode) {
+        if (!loading) {
+          if (!nextNode.isLoaded()) {
+            nextNode.load(false);
+          }
+          position++;
+        }
+        setTimeout(function () {
+          if (nextNode.isLoaded()) {
+            nextNode.setExpanded(true);
+          }
+          loadNodeAndExpand(tree, subNode, nextNode, position, !nextNode.isLoaded());
+        },300);
+      }
+      else {
+        $("#error").Popup("ERROR: File or Folder not found. Please make sure that it exist!!", 
+                                                {type: 'error', duration: 5000});
+      }
+    }
 
     /******* END ******/
 
     function openOnFavourite($elt){
       var index = parseInt($elt.attr('rel')),
           file = favourite_list[index];
-      openFile(file);
-      saveTabList ();
+      if ( file.substr(-1) === '/') {
+        file = file.slice(0, -1);
+        var subNode = file.split('/'), tree = null;
+        if (softwareDisplay) {
+          softwareDisplay = !softwareDisplay;
+          switchContent();
+        }
+        tree = $('#fileTreeFull').fancytree("getTree");
+        //XXX - hard values, get relative path form runner_workdir directory
+        if (subNode[0] === 'workspace') {
+          subNode.splice(0, 0, 'runner_workdir');
+          subNode[1] = 'project';
+        }
+        loadNodeAndExpand(tree, subNode, null, 1, false);
+      }
+      else {
+        openFile(file);
+        saveTabList ();
+      }
       $("#filelist").click();
     }
 
@@ -795,6 +881,7 @@ $(document).ready(function () {
 
     function initEditor(){
       var tmp, filename;
+      /*GET TAB List and Open files in tab*/
       var strList = getCookie("OPENED_TAB_LIST"), tabList;
       if (strList) {
         tabList = strList.split("#");
@@ -802,6 +889,7 @@ $(document).ready(function () {
           openFile(tabList[i]);
         }
       }
+      /*Load Favourite Files and Folders*/
       tmp = getCookie("FAV_FILE_LIST");
       if(tmp){
         favourite_list = tmp.split('#');
@@ -810,6 +898,10 @@ $(document).ready(function () {
         }
         for (var i=0; i<favourite_list.length; i++){
           filename = favourite_list[i].replace(/^.*(\\|\/|\:)/, '');
+          if (filename === '' && favourite_list[i].substr(-1) === '/') {
+            filename = '[DIR] ' + favourite_list[i].slice(0,
+                                                -1).replace(/^.*(\\|\/|\:)/, '');
+          }
           $("#tooltip-filelist ul").append('<li rel="'+i+
                     '"><span class="bt_close" title="Remove this element!" rel="'+i+
                     '">×</span><a href="#" rel="'+i+'" title="' + favourite_list[i]
@@ -835,11 +927,16 @@ $(document).ready(function () {
       }
       var i = favourite_list.length,
           filename = filepath.replace(/^.*(\\|\/|\:)/, '');
+      if (filename === '' && filepath.substr(-1) === '/') {
+        filename = '[DIR] ' + filepath.slice(0,-1).replace(/^.*(\\|\/|\:)/, '');
+      }
       if (i === 0){
         $("#tooltip-filelist ul").empty();
       }
       if (favourite_list.indexOf(filepath) !== -1){
-        $("#error").Popup("<b>Duplicate item!</b><br/>This files already exist in your favourite list", {type: 'alert', duration: 5000});
+        $("#error").Popup("<b>Duplicate item!</b><br/>This Item (" + filename +
+                          ") already exist in your favourite list",
+                          {type: 'alert', duration: 5000});
       }
       else{
         favourite_list.push(filepath);
@@ -860,6 +957,7 @@ $(document).ready(function () {
         $("#error").Popup("<b>Item added!</b><br/>"+filename+" has been added to your favourite list.", {type: 'confirm', duration: 3000});
       }
     }
+    
 
 
     /************ INITIALIZE FUNTIONS CALLS  ************************/
@@ -939,7 +1037,7 @@ $(document).ready(function () {
       $("#plist li").each(function (index) {
           var elt = $(this).find("input:checkbox");
           if (elt.is(":checked")) {
-              developList[i] = workdir + "/" + elt.val();
+              developList[i] = "workspace" + "/" + elt.val();
               i += 1;
               elt.attr("checked", false);
           }
@@ -963,7 +1061,7 @@ $(document).ready(function () {
         return false;
       }
       config.loadModule("ace/ext/searchbox", function(e) {
-        e.Search(getCurrentEditor())
+        e.Search(getCurrentEditor());
       });
       $("#option").click();
       return false;
@@ -974,7 +1072,7 @@ $(document).ready(function () {
         return false;
       }
       config.loadModule("ace/ext/searchbox", function(e) {
-        e.Search(getCurrentEditor(), true)
+        e.Search(getCurrentEditor(), true);
       });
       $("#option").click();
       return false;
