@@ -139,7 +139,7 @@ def getCurrentSoftwareReleaseProfile(config):
   """
   try:
     software_folder = open(
-        os.path.join(config['etc_dir'], ".project")).read()
+        os.path.join(config['etc_dir'], ".project")).read().rstrip()
     return realpath(
         config, os.path.join(software_folder, config['software_profile']))
   # XXXX No Comments
@@ -156,7 +156,7 @@ def requestInstance(config, software_type=None):
     # Write it to conf file for later use
     open(software_type_path, 'w').write(software_type)
   elif os.path.exists(software_type_path):
-    software_type = open(software_type_path).read()
+    software_type = open(software_type_path).read().rstrip()
   else:
     software_type = 'default'
 
@@ -268,7 +268,10 @@ def isSoftwareRunning(config=None):
   """
     Return True if slapos is still running and false if slapos if not
   """
-  # XXX-Marco what is 'config' for?
+  # XXX-Cedric Hardcoded pidfile
+  if config:
+    slapgrid_pid = os.path.join(config['run_dir'], 'slapgrid-sr.pid')
+    return isPidFileProcessRunning(slapgrid_pid)
   return isRunning('slapgrid-sr')
 
 
@@ -370,7 +373,10 @@ def isInstanceRunning(config=None):
   """
     Return True if slapos is still running and False otherwise
   """
-  # XXX-Marco what is 'config' for?
+  # XXX-Cedric Hardcoded pidfile
+  if config:
+    slapgrid_pid = os.path.join(config['run_dir'], 'slapgrid-cp.pid')
+    return isPidFileProcessRunning(slapgrid_pid)
   return isRunning('slapgrid-cp')
 
 
